@@ -22,7 +22,7 @@ async def _main(args):
     disable_stdout_buffering()
     ebus = create_ebus(args)
     await async_load_msgdefs(ebus, args)
-    msgdefs = ebus.msgdefs.resolve(args.patterns.split(";"))
+    msgdefs = ebus.msgdefs.resolve(args.patterns)
     print(f"Listening to {msgdefs.summary()}")
     if msgdefs:
         async for msg in ebus.async_listen(msgdefs=msgdefs):
