@@ -1,4 +1,5 @@
 """State Command."""
+from ..const import OK
 from .common import create_ebus, disable_stdout_buffering
 
 
@@ -11,4 +12,11 @@ def parse_args(subparsers):
 async def _main(args):
     disable_stdout_buffering()
     ebus = create_ebus(args)
-    print(await ebus.async_get_state())
+    state = await ebus.async_get_state()
+    if state != OK:
+        raise Broken(state)
+    print(state)
+
+
+class Broken(RuntimeError):
+    """Broken State"""
