@@ -26,6 +26,11 @@ class Msg(collections.namedtuple("_Msg", "msgdef fields")):
         """Identifier."""
         return self.msgdef.ident
 
+    @property
+    def values(self):
+        """Values."""
+        return tuple(field.value for field in self.fields)
+
 
 class Field(collections.namedtuple("_Field", "fielddef value")):
 
@@ -65,15 +70,13 @@ def filter_msg(msg=None, msgdefs=None):
                 if ident == msgdef.ident:
                     if msg.msgdef == msgdef:
                         return msg
-                    elif msg.valid:
+                    else:
                         fields = tuple(
                             Field(field.fielddef, field.value)
                             for field in msg.fields
                             if field.fielddef in msgdef.fields
                         )
                         return Msg(msgdef, fields)
-                    else:
-                        return msg
         else:
             return msg
     return None
@@ -100,3 +103,8 @@ class BrokenMsg:
 
     def __repr__(self):
         return repr_(self, (self.msgdef.ident, self.error))
+
+    @property
+    def values(self):
+        """Values."""
+        return []
